@@ -21,18 +21,6 @@ BASE_CONFIG = {
     'XTRACK_GLOBAL_XY_LIMIT': 1.0,
 }
 
-FREEZE_ENERGY = {
-    'FREEZE_VAR_delta': True,
-    'FREEZE_VAR_ptau': True,
-    'FREEZE_VAR_rpp': True,
-    'FREEZE_VAR_rvv': True,
-}
-
-FREEZE_LONGITUDINAL = {
-    **FREEZE_ENERGY,
-    'FREEZE_VAR_zeta': True,
-}
-
 ONLY_XTRACK_ELEMENTS = [
     Drift,
     Multipole,
@@ -46,6 +34,7 @@ ONLY_XTRACK_ELEMENTS = [
     Marker,
     ReferenceEnergyIncrease,
     Cavity,
+    CrabCavity,
     Elens,
     Wire,
     Solenoid,
@@ -59,21 +48,36 @@ ONLY_XTRACK_ELEMENTS = [
     LineSegmentMap,
     FirstOrderTaylorMap,
     NonLinearLens,
-    # Slices
+    # Drift Slices
     DriftSlice,
     DriftSliceBend,
     DriftSliceRBend,
     DriftSliceOctupole,
     DriftSliceQuadrupole,
     DriftSliceSextupole,
+    DriftSliceCavity,
+    DriftSliceCrabCavity,
+    DriftSliceMultipole,
+    # Thick slices
     ThickSliceBend,
     ThickSliceRBend,
     ThickSliceOctupole,
     ThickSliceQuadrupole,
     ThickSliceSextupole,
     ThickSliceUniformSolenoid,
+    ThickSliceCavity,
+    ThickSliceCrabCavity,
+    ThickSliceMultipole,
+    # Thin slices
     ThinSliceBend,
     ThinSliceRBend,
+    ThinSliceOctupole,
+    ThinSliceQuadrupole,
+    ThinSliceSextupole,
+    ThinSliceCavity,
+    ThinSliceCrabCavity,
+    ThinSliceMultipole,
+    # Edge slices
     ThinSliceBendEntry,
     ThinSliceBendExit,
     ThinSliceRBendEntry,
@@ -86,9 +90,7 @@ ONLY_XTRACK_ELEMENTS = [
     ThinSliceUniformSolenoidExit,
     ThinSliceOctupoleEntry,
     ThinSliceOctupoleExit,
-    ThinSliceOctupole,
-    ThinSliceQuadrupole,
-    ThinSliceSextupole,
+
     # Transformations
     XYShift,
     ZetaShift,
@@ -169,56 +171,8 @@ kernel_definitions = [
         },
         'classes': ONLY_XTRACK_ELEMENTS + NO_SYNRAD_ELEMENTS + DEFAULT_XF_ELEMENTS + DEFAULT_XCOLL_ELEMENTS,
     }),
-    ('default_backtrack', {
-        'config': {**BASE_CONFIG, 'XSUITE_BACKTRACK': True},
-        'classes': ONLY_XTRACK_ELEMENTS + NO_SYNRAD_ELEMENTS + DEFAULT_XF_ELEMENTS + DEFAULT_XCOLL_ELEMENTS,
-    }),
-    ('only_xtrack_backtrack_no_limit', {
-        'config': {
-            **BASE_CONFIG,
-            'XSUITE_BACKTRACK': True,
-            'XTRACK_GLOBAL_XY_LIMIT': False,
-        },
-        'classes': ONLY_XTRACK_ELEMENTS + NO_SYNRAD_ELEMENTS + DEFAULT_XF_ELEMENTS + DEFAULT_XCOLL_ELEMENTS,
-    }),
-    ('frozen_longitudinal', {
-        'config': {**BASE_CONFIG, **FREEZE_LONGITUDINAL},
-        'classes': ONLY_XTRACK_ELEMENTS + NO_SYNRAD_ELEMENTS + DEFAULT_XF_ELEMENTS + DEFAULT_XCOLL_ELEMENTS,
-    }),
-    ('frozen_energy', {
-        'config': {**BASE_CONFIG, **FREEZE_ENERGY},
-        'classes': ONLY_XTRACK_ELEMENTS + NO_SYNRAD_ELEMENTS + DEFAULT_XF_ELEMENTS + DEFAULT_XCOLL_ELEMENTS,
-    }),
-    ('backtrack_frozen_energy', {
-        'config': {**BASE_CONFIG, **FREEZE_ENERGY, 'XSUITE_BACKTRACK': True},
-        'classes': ONLY_XTRACK_ELEMENTS + NO_SYNRAD_ELEMENTS + DEFAULT_XF_ELEMENTS + DEFAULT_XCOLL_ELEMENTS,
-    }),
-    ('mirror_frozen_energy', {
-        'config': {**BASE_CONFIG, **FREEZE_ENERGY, 'XSUITE_MIRROR': True},
-        'classes': ONLY_XTRACK_ELEMENTS + NO_SYNRAD_ELEMENTS + DEFAULT_XF_ELEMENTS + DEFAULT_XCOLL_ELEMENTS,
-    }),
-    ('only_xtrack_taper', {
-        'config': {
-            **BASE_CONFIG,
-            'XTRACK_MULTIPOLE_NO_SYNRAD': False,
-            'XTRACK_MULTIPOLE_TAPER': True,
-            'XTRACK_DIPOLEEDGE_TAPER': True,
-        },
-        'classes': ONLY_XTRACK_ELEMENTS,
-    }),
     ('only_xtrack_with_synrad', {
         'config': {**BASE_CONFIG, 'XTRACK_MULTIPOLE_NO_SYNRAD': False},
         'classes': ONLY_XTRACK_ELEMENTS,
     }),
-    ('only_xtrack_with_synrad_kick_as_co', {
-        'config': {
-            **BASE_CONFIG, 'XTRACK_MULTIPOLE_NO_SYNRAD': False,
-            'XTRACK_SYNRAD_KICK_SAME_AS_FIRST': True
-        },
-        'classes': ONLY_XTRACK_ELEMENTS,
-    }),
-    ('only_xtrack_with_synrad_frozen_energy', { # for spin twiss
-        'config': {**BASE_CONFIG, **FREEZE_ENERGY, 'XTRACK_MULTIPOLE_NO_SYNRAD': False,},
-        'classes': ONLY_XTRACK_ELEMENTS + NO_SYNRAD_ELEMENTS + DEFAULT_XF_ELEMENTS + DEFAULT_XCOLL_ELEMENTS,
-    }),
 ]
